@@ -17,11 +17,13 @@ PDF::Table. Also it can be used to bootstrap your code.
 # then look for PDFpref file and read A or B forms
 my ($PDFpref, $rcA, $rcB); # which is available?
 my $prefFile = "./PDFpref";
+my $prefix = 0;  # by default, do not add a prefix to the output name
 my $prefDefault = "B"; # PDF::Builder default if no prefFile, or both installed
 if (@ARGV) {
     # A or -A argument: set PDFpref to A else B
     if ($ARGV[0] =~ m/^-?([AB])/i) {
 	$PDFpref = uc($1);
+	$prefix = 1;
     } else {
 	print STDERR "Unknown command line flag $ARGV[0] ignored.\n";
     }
@@ -78,12 +80,14 @@ if (!$rcA && !$rcB) {
 }
 # -------------
 
-our $VERSION = '1.003'; # VERSION
-our $LAST_UPDATE = '1.001'; # manually update whenever code is changed
+our $VERSION = '1.005'; # VERSION
+our $LAST_UPDATE = '1.004'; # manually update whenever code is changed
 
 my $outfile = $0;
 if ($outfile =~ m#[\\/]([^\\/]+)$#) { $outfile = $1; }
 $outfile =~ s/\.pl$/.pdf/;
+# command line -A or -B adds A_ or B_ to outfile
+if ($prefix) { $outfile = $PDFpref . "_" . $outfile; }
 
 my $pdftable = PDF::Table->new();
 # -------------
@@ -180,7 +184,7 @@ $pdftable->table(
 			               # larger font, right-justified, own bg.
 			min_w      => 250,
 			justify    => "right",
-			font       => $pdf->corefont( "Times", -encoding => "latin1" ),
+			font       => $pdf->corefont( "Times-Roman", -encoding => "latin1" ),
 			font_size  => 14, 
 			fg_color   => 'white',
 			bg_color   => '#8CA6C5',
