@@ -7,10 +7,10 @@ our %test = ( a => 1 );
 our %required = (
     x       => 10,
     w       => 300,
-    start_y => 700,
+    y       => 700,
     next_y  => 600,
-    start_h => 100,
+    h       => 100,
     next_h  => 500,
 );
 
-return 1;
+1;
